/**
 * Demo of app project.
 * @function apemanAppStatic
 * @param {string|string.} root - Root directory path.
 * @param {object} [options] - Optional settings.
 * @param {string} [options.cwd=process.cwd()] - Working directory path.
 * @returns {function} - Defined app function.
 */

'use strict'

const assert = require('assert')
const path = require('path')
const koaStatic = require('koa-static')

const debug = require('debug')('apeman:app:static')

/** @lends create */
function create (root, options = {}) {
  assert.ok(root, 'root is required.')

  let basedir = options.cwd || process.cwd()

  let app = [].concat(root || []).map((root) => {
    root = path.resolve(basedir, root)
    debug(`Register root: ${root}`)
    return koaStatic(root, options)
  })

  Object.assign(app, {
    // Description of this app.
    $desc: 'Serve static files.'
  })
  return app
}

module.exports = create
